/***************************************************************************
                          Preferences.cpp  -  description
                             -------------------
    begin                : Sam Apr 27 2002
    copyright            : (C) 2002 by Andreas Scherf
    email                : scherfa@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <qtextstream.h>
#include "Preferences.h"
// debug
#include <iostream>


Preferences::Preferences (QWidget * parent, const char *name) : PreferencesGUI (parent, name, true)
{
}

Preferences::~Preferences ()
{
}


/** No descriptions */
void Preferences::setFilename (const QString & fn) {
    filename = fn;
    LineEdit1->setText (fn);
}

void Preferences::setStartTime (const QString & time) {
    timestring = time;
    TimeEdit1->setTime (QTime::fromString (time, Qt::TextDate));
}

void Preferences::setFormat (int num) {
formatnumber=num;
if (num == RTLFormat) 
    ComboBox1->setCurrentText("RTLFormat");
else     
ComboBox1->setCurrentText("TimeFormat");
}

void Preferences::setFormatStrings () {

        ComboBox1->insertItem("TimeFormat",-1);
        ComboBox1->insertItem("RTLFormat",-1);
}

QString Preferences::retFilename () {
    return LineEdit1->text ();
}

QTime Preferences::retStartTime () {
    return TimeEdit1->time ();
}

int Preferences::retFormat() {
    QString st;
    int num=0;
    st=ComboBox1->currentText();
    if (st == "RTLFormat") {
    num=RTLFormat; 
    }
    else {
    num=TimeFormat;
    }  
    formatnumber=num;  
    return num;    
}

QString Preferences::getFilename () {
    return filename;
}

QString Preferences::getStartTime () {
    return timestring;
}

int Preferences::getFormat() {
    return formatnumber;
}

bool Preferences::readPreferences () {
    QDir::setCurrent (CONFIGDIR);
    QFile           f (CONFIGFILE);
    setFormatStrings();
    if (f.open (IO_ReadOnly)) {	// file opened successfully
        QTextStream     t (&f);	// use a text stream
        QString         s,result;
        QStringList sl;
        while (!t.eof ()) {		// until end of file...
            s = t.readLine ();	// line of text excluding '\n'
            if (!s.startsWith ("#")) {
                if (s.contains ("starttime", FALSE) > 0) {
                    setStartTime (s.section ('=', -1));
                } else if (s.contains ("filename", FALSE) > 0) {
                    setFilename (s.section ('=', -1));
                } else if (s.contains ("format",FALSE) > 0) {
                    setFormat(s.section('=',-1).toInt());
                }
            }
        }
    } else {
        writePreferences ();
        setFilename (DEFAULTTIMEFILE);
        setStartTime (QTime::currentTime ().toString ());
        return FALSE;
    }
    f.close ();
    return TRUE;

}

QString Preferences::createHeader () {
    QString         t;
    t.append ("# TimeCounter ");
    t.append (VERSION);
    t.append (" ConfigFile\n");
    t.append ("# (c) 2002 by Andreas Scherf\n");
    return t;
}

bool Preferences::writePreferences () {
    QDir::setCurrent (CONFIGDIR);
    QFile           f (CONFIGFILE);
    if (f.exists ()) {
        if (f.open (IO_WriteOnly)) {
            QTextStream     t (&f);
            t << createHeader ();
            t << "filename=" << retFilename () << endl;
            t << "starttime=" << retStartTime ().toString ("hh:mm:ss") << endl;
            t << "format=" << retFormat() << endl;

        }
    } else if (f.open (IO_WriteOnly)) {
        QTextStream     t (&f);
        t << createHeader ();
        t << "filename=" << DEFAULTTIMEFILE << endl;
        t << "starttime=" << QTime::currentTime ().toString ("hh:mm:ss") << endl;
        t << "format=" << 0 << endl;
    }
    f.close ();
    return TRUE;
}
