/***************************************************************************
                          Time.cpp  -  description
                             -------------------
    begin                : Mon Apr 29 2002
    copyright            : (C) 2002 by Andreas Scherf
    email                : scherfa@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "Time.h"

#define TIMEFORMAT "hh:mm:ss.zzz"

Time::Time (QWidget * parent, const char *name) : TimeGUI (parent, name, true)
{
    AnalogClock1->setLabelText( trUtf8("Aktuelle Uhrzeit"));
    AnalogClock2->setLabelText( trUtf8("Teilnehmer im Ziel"));
    AnalogClock3->setLabelText( trUtf8("Aktuelle Laufzeit"));
    AnalogClock3->setTimeFormat(TIMEFORMAT);
    AnalogClock1->setShowCTime(TRUE);
    AnalogClock1->start();
    AnalogClock2->setMessageFont(QFont ("helvetica", 30));
    AnalogClock2->setDisplayTime("00:00:00");
    AnalogClock2->setMessageText(0);
    AnalogClock3->start();
    
    ListBox1->clear();
    //AnalogClock3->
    LineEdit1->setReadOnly ( TRUE );
    filename = strdup ("zeiten.lzt");
    timenumber = 1;
    formatnumber = Preferences::TimeFormat; //KRunning default
}

Time::~Time ()
{
    //free(filename);
}

//
// Stores aktual time to file ... ?? Im Time Code ???
//
void Time::keyPressEvent (QKeyEvent * k) {
    QTime t;
    if (k->key () == Qt::Key_Return) {
        QDir::setCurrent (QDir::homeDirPath ());
        fstream         FS (filename, ios::in | ios::out);
        FS.seekp (0, ios::end);
        t=AnalogClock3->getTimeDiff (QTime::currentTime ());
        switch (formatnumber) {
        case Preferences::RTLFormat:   // RTLCode
            FS << timenumber << " " << getRTLCode (t) << endl;
            break;
        case Preferences::TimeFormat:   // Normal Time
            FS << timenumber << " " << t.toString(TIMEFORMAT) << endl;
            break;
        default:
            cerr << "Format Error = " << formatnumber<< endl;
        }


        // Do some output
        ListBox1->insertItem(t.toString(TIMEFORMAT),-1);
        AnalogClock2->setDisplayTime(t.toString());
        AnalogClock2->setMessageText (timenumber);

        timenumber++;

        FS.close ();
    } else {
        // Display a warning
    }
}



/** getRTLCode - Decodes the Time that it matches the Timecode from RTL
 ** below there is the decode Sequence from KRunning ...
 ** seconds = (atoi (string[1]) / 100) % 100;                          // Sekunden
 ** seconds = seconds + (((atoi (string[1]) / 10000) % 60) * 60);      // Minuten
 ** seconds = seconds + (((atoi (string[1]) / 10000) / 60) * 3600);    // Stunden
 ** @author Andreas Scherf
 ** @version 0.2
*/
// in time
uint Time::getRTLCode (const QTime & t) {
    uint            result;
    result = t.second () * 100;
    result += t.minute () * 10000;
    result += (t.hour () * 600000);	///3600;  //ERROR
    return result;
}


void Time::setFilename(const QString &name) {
    filename=strdup(name);
    LineEdit1->setText(name);
}

void Time::setStartTime(const QString &time) {
    AnalogClock3->setStartTime(time);
}

void Time::setFormat(int f) {
    formatnumber=f;
}
