/***************************************************************************
                          timecounter.cpp  -  description
                             -------------------
    begin                : Fre Apr 26 13:49:54 CEST 2002
    copyright            : (C) 2002 by Andreas Scherf
    email                : scherfa@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <qaccel.h>
#include "DigitalClock.h"
#include "Preferences.h"
#include "Time.h"

#include "timecounter.h"
#include "filesave.xpm"
#include "fileopen.xpm"
#include "filenew.xpm"

TimeCounterApp::TimeCounterApp ()
{
    setCaption (tr ("TimeCounter " VERSION));

    ///////////////////////////////////////////////////////////////////
    // call inits to invoke all other construction parts
    initActions ();
    initMenuBar ();
    initToolBar ();
    initStatusBar ();

    initDoc ();
    initView ();

    viewToolBar->setOn (true);
    viewStatusBar->setOn (true);
}

TimeCounterApp::~TimeCounterApp ()
{
}

/** initializes all QActions of the application */
void
TimeCounterApp::initActions ()
{

    QPixmap         openIcon, saveIcon, newIcon;
    newIcon = QPixmap (filenew);
    openIcon = QPixmap (fileopen);
    saveIcon = QPixmap (filesave);


    fileNew = new QAction (tr ("Count Times"), newIcon, tr ("&Times"), QAccel::stringToKey (tr ("Ctrl+T")), this);
    fileNew->setStatusTip (tr ("Shows the timecount screen"));
    fileNew->setWhatsThis (tr ("New File\n\nCreates a new document"));
    connect (fileNew, SIGNAL (activated ()), this, SLOT (slotFileNew ()));
/*
    fileOpen = new QAction (tr ("Open File"), openIcon, tr ("&Open..."), 0, this);
    fileOpen->setStatusTip (tr ("Opens an existing document"));
    fileOpen->setWhatsThis (tr ("Open File\n\nOpens an existing document"));
    connect (fileOpen, SIGNAL (activated ()), this, SLOT (slotFileOpen ()));
*/
    fileSave = new QAction (tr ("Count Times Fullscreen"), openIcon, tr ("&Times (Full)"), QAccel::stringToKey (tr ("Ctrl+F")), this);
    fileSave->setStatusTip (tr ("Shows the timecount screen (Fullscreen)"));
  //  fileSave->setWhatsThis (tr ("Save File.\n\nSaves the actual document"));
    connect (fileSave, SIGNAL (activated ()), this, SLOT (slotShowFullScreen ()));

  /*  fileSaveAs = new QAction (tr ("Save File As"), tr ("Save &as..."), 0, this);
    fileSaveAs->setStatusTip (tr ("Saves the actual document under a new filename"));
    fileSaveAs->setWhatsThis (tr ("Save As\n\nSaves the actual document under a new filename"));
    connect (fileSaveAs, SIGNAL (activated ()), this, SLOT (slotFileSave ()));
*/
    fileClose = new QAction (tr ("Close File"), tr ("&Close"), QAccel::stringToKey (tr ("Ctrl+W")), this);
    fileClose->setStatusTip (tr ("Closes the actual document"));
    fileClose->setWhatsThis (tr ("Close File\n\nCloses the actual document"));
    connect (fileClose, SIGNAL (activated ()), this, SLOT (slotFileClose ()));

    filePreferences = new QAction (tr ("Preferences"), tr ("P&references"), QAccel::stringToKey (tr ("Ctrl+R")), this);
    connect (filePreferences, SIGNAL (activated ()), this, SLOT (slotFilePreferences ()));

    filePrint = new QAction (tr ("Print File"), tr ("&Print"), QAccel::stringToKey (tr ("Ctrl+P")), this);
    filePrint->setStatusTip (tr ("Prints out the actual document"));
    filePrint->setWhatsThis (tr ("Print File\n\nPrints out the actual document"));
    connect (filePrint, SIGNAL (activated ()), this, SLOT (slotFilePrint ()));

    fileQuit = new QAction (tr ("Exit"), tr ("E&xit"), QAccel::stringToKey (tr ("Ctrl+Q")), this);
    fileQuit->setStatusTip (tr ("Quits the application"));
    fileQuit->setWhatsThis (tr ("Exit\n\nQuits the application"));
    connect (fileQuit, SIGNAL (activated ()), this, SLOT (slotFileQuit ()));

    viewToolBar = new QAction (tr ("Toolbar"), tr ("Tool&bar"), 0, this, 0, true);
    viewToolBar->setStatusTip (tr ("Enables/disables the toolbar"));
    viewToolBar->setWhatsThis (tr ("Toolbar\n\nEnables/disables the toolbar"));
    connect (viewToolBar, SIGNAL (toggled (bool)), this, SLOT (slotViewToolBar (bool)));

    viewStatusBar = new QAction (tr ("Statusbar"), tr ("&Statusbar"), 0, this, 0, true);
    viewStatusBar->setStatusTip (tr ("Enables/disables the statusbar"));
    viewStatusBar->setWhatsThis (tr ("Statusbar\n\nEnables/disables the statusbar"));
    connect (viewStatusBar, SIGNAL (toggled (bool)), this, SLOT (slotViewStatusBar (bool)));

    helpAboutApp = new QAction (tr ("About"), tr ("&About..."), 0, this);
    helpAboutApp->setStatusTip (tr ("About the application"));
    helpAboutApp->setWhatsThis (tr ("About\n\nAbout the application"));
    connect (helpAboutApp, SIGNAL (activated ()), this, SLOT (slotHelpAbout ()));

}

void
TimeCounterApp::initMenuBar ()
{
    ///////////////////////////////////////////////////////////////////
    // MENUBAR

    ///////////////////////////////////////////////////////////////////
    // menuBar entry fileMenu
    fileMenu = new QPopupMenu ();
    fileNew->addTo (fileMenu);
  //  fileOpen->addTo (fileMenu);
    fileClose->addTo (fileMenu);
    fileMenu->insertSeparator ();
    fileSave->addTo (fileMenu);
  //  fileSaveAs->addTo (fileMenu);
    fileMenu->insertSeparator ();
    filePreferences->addTo (fileMenu);
    fileMenu->insertSeparator ();
    filePrint->addTo (fileMenu);
    fileMenu->insertSeparator ();
    fileQuit->addTo (fileMenu);


    ///////////////////////////////////////////////////////////////////
    // menuBar entry viewMenu
    viewMenu = new QPopupMenu ();
    viewMenu->setCheckable (true);
    viewToolBar->addTo (viewMenu);
    viewStatusBar->addTo (viewMenu);
    ///////////////////////////////////////////////////////////////////
    // EDIT YOUR APPLICATION SPECIFIC MENUENTRIES HERE

    ///////////////////////////////////////////////////////////////////
    // menuBar entry helpMenu
    helpMenu = new QPopupMenu ();
    helpAboutApp->addTo (helpMenu);

    ///////////////////////////////////////////////////////////////////
    // MENUBAR CONFIGURATION
    menuBar ()->insertItem (tr ("&File"), fileMenu);
    menuBar ()->insertItem (tr ("&View"), viewMenu);
    menuBar ()->insertSeparator ();
    menuBar ()->insertItem (tr ("&Help"), helpMenu);

}

void
TimeCounterApp::initToolBar ()
{
    ///////////////////////////////////////////////////////////////////
    // TOOLBAR
    fileToolbar = new QToolBar (this, "file operations");
    fileNew->addTo (fileToolbar);
  //  fileOpen->addTo (fileToolbar);
    fileSave->addTo (fileToolbar);
    fileToolbar->addSeparator ();
    QWhatsThis::whatsThisButton (fileToolbar);

}

void
TimeCounterApp::initStatusBar ()
{
    ///////////////////////////////////////////////////////////////////
    //STATUSBAR
    statusBar ()->message (tr ("Ready."), 2000);
}

void
TimeCounterApp::initDoc ()
{
    doc = new TimeCounterDoc ();
}

void
TimeCounterApp::initView ()
{
    ////////////////////////////////////////////////////////////////////
    // set the main widget here
    view = new TimeCounterView (this, doc);
    setCentralWidget (view);
}

bool
TimeCounterApp::queryExit ()
{
    int             exit = QMessageBox::information (this, tr ("Quit..."),
                           tr ("Do your really want to quit?"),
                           QMessageBox::Ok, QMessageBox::Cancel);

    if (exit == 1) {

    } else {

    };

    return (exit == 1);
}

/////////////////////////////////////////////////////////////////////
// SLOT IMPLEMENTATION
/////////////////////////////////////////////////////////////////////


void
TimeCounterApp::slotFileNew ()
{
    statusBar ()->message (tr ("Show time screen..."));
    Preferences    *pref = new Preferences ();
    pref->readPreferences ();

    Time *time = new Time (this,"timescreen");
    time->resize (640, 480);
    time->setStartTime(pref->getStartTime());
    time->setFilename(pref->getFilename());
    time->setFormat(pref->getFormat());
    time->show();
    delete pref;
    statusBar ()->message (tr ("Ready."));
}

void 
TimeCounterApp::slotShowFullScreen() {
  statusBar ()->message (tr ("Show times fullscreen..."));
    Preferences    *pref = new Preferences ();
    pref->readPreferences ();

    Time *time = new Time (this,"fulltimescreen");
    time->setStartTime(pref->getStartTime());
    time->setFilename(pref->getFilename());
    time->setFormat(pref->getFormat());
    time->showFullScreen();
    delete pref;
    statusBar ()->message (tr ("Ready."));
}

void
TimeCounterApp::slotFileOpen ()
{
    statusBar ()->message (tr ("Opening file..."));

    QString         fileName = QFileDialog::getOpenFileName (0, 0, this);
    if (!fileName.isEmpty ()) {
        doc->load (fileName);
        setCaption (fileName);
        QString         message = tr ("Loaded document: ") + fileName;
        statusBar ()->message (message, 2000);
    } else {
        statusBar ()->message (tr ("Opening aborted"), 2000);
    }
}


void
TimeCounterApp::slotFileSave ()
{
    statusBar ()->message (tr ("Saving file..."));
    doc->save ();
    statusBar ()->message (tr ("Ready."));
}

void
TimeCounterApp::slotFileSaveAs ()
{
    statusBar ()->message (tr ("Saving file under new filename..."));
    QString         fn = QFileDialog::getSaveFileName (0, 0, this);
    if (!fn.isEmpty ()) {
        doc->saveAs (fn);
    } else {
        statusBar ()->message (tr ("Saving aborted"), 2000);
    }

    statusBar ()->message (tr ("Ready."));
}

void
TimeCounterApp::slotFileClose ()
{
    statusBar ()->message (tr ("Closing file..."));

    statusBar ()->message (tr ("Ready."));
}

void
TimeCounterApp::slotFilePreferences ()
{
    statusBar ()->message (tr ("Preferences ..."));
    Preferences    *pref = new Preferences ();

    pref->readPreferences ();
    if (pref->exec () == QDialog::Accepted) {
        pref->writePreferences ();
        //workingDirectory = dlg->url();
    }
    delete          pref;
    statusBar ()->message (tr ("Ready."));
}

void
TimeCounterApp::slotFilePrint ()
{
    statusBar ()->message (tr ("Printing..."));
    QPrinter        printer;
    if (printer.setup (this)) {
        QPainter        painter;
        painter.begin (&printer);

        ///////////////////////////////////////////////////////////////////
        // TODO: Define printing by using the QPainter methods here

        painter.end ();
    };

    statusBar ()->message (tr ("Ready."));
}

void
TimeCounterApp::slotFileQuit ()
{
    statusBar ()->message (tr ("Exiting application..."));
    ///////////////////////////////////////////////////////////////////
    // exits the Application
    if (doc->isModified ()) {
        if (queryExit ()) {
            qApp->quit ();
        } else {

        };
    } else if (queryExit ()) {
        qApp->quit ();
    };

    statusBar ()->message (tr ("Ready."));
}

void
TimeCounterApp::slotViewToolBar (bool toggle)
{
    statusBar ()->message (tr ("Toggle toolbar..."));
    ///////////////////////////////////////////////////////////////////
    // turn Toolbar on or off

    if (toggle == false) {
        fileToolbar->hide ();
    } else {
        fileToolbar->show ();
    };

    statusBar ()->message (tr ("Ready."));
}

void
TimeCounterApp::slotViewStatusBar (bool toggle)
{
    statusBar ()->message (tr ("Toggle statusbar..."));
    ///////////////////////////////////////////////////////////////////
    //turn Statusbar on or off

    if (toggle == false) {
        statusBar ()->hide ();
    } else {
        statusBar ()->show ();
    }

    statusBar ()->message (tr ("Ready."));
}

void
TimeCounterApp::slotHelpAbout ()
{
    QMessageBox::about (this, tr ("About..."), tr ("TimeCounter\nVersion " VERSION "\n(c) 2002 by Andreas Scherf"));
}
